==> activity-center-api-3.6.26-20250907.032333-3-sources.jar: cn/com/duiba/activity/center/api/dto/HdTaskConfigDto.java <==
package cn.com.duiba.activity.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class HdTaskConfigDto implements Serializable {


    private static final long serialVersionUID = 1398436280788130409L;
    /**
     * 主键
     */
    private Long id;

    /**
     * 应用id
     */
    private Long appId;

    /**
     * 活动id
     */
    private Long opId;

    /**
     * 任务code
     */
    private String taskCode;

    /**
     * 任务名称
     */
    private String taskName;

    /**
     * 任务副标题
     */
    private String taskSubTitle;

    /**
     * day 每日
     */
    private String rewardLimitType;

    /**
     * 限制次数
     */
    private Integer rewardLimitTimes;

    /**
     * 奖励次数
     */
    private Integer rewardTimes;

    /**
     * day 当日 forever 永久
     */
    private String rewardValidity;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOpId() {
        return opId;
    }

    public void setOpId(Long opId) {
        this.opId = opId;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public String getTaskSubTitle() {
        return taskSubTitle;
    }

    public void setTaskSubTitle(String taskSubTitle) {
        this.taskSubTitle = taskSubTitle;
    }

    public String getRewardLimitType() {
        return rewardLimitType;
    }

    public void setRewardLimitType(String rewardLimitType) {
        this.rewardLimitType = rewardLimitType;
    }

    public Integer getRewardLimitTimes() {
        return rewardLimitTimes;
    }

    public void setRewardLimitTimes(Integer rewardLimitTimes) {
        this.rewardLimitTimes = rewardLimitTimes;
    }

    public Integer getRewardTimes() {
        return rewardTimes;
    }

    public void setRewardTimes(Integer rewardTimes) {
        this.rewardTimes = rewardTimes;
    }

    public String getRewardValidity() {
        return rewardValidity;
    }

    public void setRewardValidity(String rewardValidity) {
        this.rewardValidity = rewardValidity;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-3.6.29-20251010.021834-6-sources.jar: cn/com/duiba/activity/center/api/dto/HdTaskConfigDto.java <==
package cn.com.duiba.activity.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class HdTaskConfigDto implements Serializable {


    private static final long serialVersionUID = 1398436280788130409L;
    /**
     * 主键
     */
    private Long id;

    /**
     * 应用id
     */
    private Long appId;

    /**
     * 活动id
     */
    private Long opId;

    /**
     * 任务code
     */
    private String taskCode;

    /**
     * 任务名称
     */
    private String taskName;

    /**
     * lx任务主标题
     */
    private String lxTaskMainTitle;

    /**
     * 任务副标题
     */
    private String taskSubTitle;

    /**
     * lx任务图标
     */
    private String lxicon;

    /**
     * lx任务完成阈值
     */
    private Integer lxTaskCompleteThreshold;

    /**
     * day 每日
     */
    private String rewardLimitType;

    /**
     * 限制次数
     */
    private Integer rewardLimitTimes;

    /**
     * 奖励次数
     */
    private Integer rewardTimes;

    /**
     * day 当日 forever 永久
     */
    private String rewardValidity;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public String getLxTaskMainTitle() {
        return lxTaskMainTitle;
    }

    public void setLxTaskMainTitle(String lxTaskMainTitle) {
        this.lxTaskMainTitle = lxTaskMainTitle;
    }

    public String getLxicon() {
        return lxicon;
    }

    public void setLxicon(String lxicon) {
        this.lxicon = lxicon;
    }

    public Integer getLxTaskCompleteThreshold() {
        return lxTaskCompleteThreshold;
    }

    public void setLxTaskCompleteThreshold(Integer lxTaskCompleteThreshold) {
        this.lxTaskCompleteThreshold = lxTaskCompleteThreshold;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOpId() {
        return opId;
    }

    public void setOpId(Long opId) {
        this.opId = opId;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public String getTaskSubTitle() {
        return taskSubTitle;
    }

    public void setTaskSubTitle(String taskSubTitle) {
        this.taskSubTitle = taskSubTitle;
    }

    public String getRewardLimitType() {
        return rewardLimitType;
    }

    public void setRewardLimitType(String rewardLimitType) {
        this.rewardLimitType = rewardLimitType;
    }

    public Integer getRewardLimitTimes() {
        return rewardLimitTimes;
    }

    public void setRewardLimitTimes(Integer rewardLimitTimes) {
        this.rewardLimitTimes = rewardLimitTimes;
    }

    public Integer getRewardTimes() {
        return rewardTimes;
    }

    public void setRewardTimes(Integer rewardTimes) {
        this.rewardTimes = rewardTimes;
    }

    public String getRewardValidity() {
        return rewardValidity;
    }

    public void setRewardValidity(String rewardValidity) {
        this.rewardValidity = rewardValidity;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
